@@ -1,11 +1,15 @@
-from typing import Union, Any
+from typing import Union, Any, TypeVar
 
+import amino
 from amino import maybe
-from amino.either import Right, Left
+from amino.either import Right, Left, Either
 from amino.func import call_by_name
 
+A = TypeVar('A')
+B = TypeVar('B')
 
-class Boolean(object):
+
+class Boolean:
 
     def __init__(self, value: Union['Boolean', bool]) -> None:
         self.value = bool(value)
@@ -41,13 +45,16 @@ class Boolean(object):
     def flat_either_call(self, l, r):
         return r() if self else Left(l)
 
-    def e(self, l, r):
+    def e(self, l: A, r: B) -> Either[A, B]:
         return Right(call_by_name(r)) if self else Left(call_by_name(l))
 
     def flat_e(self, l, r):
         return call_by_name(r) if self else Left(call_by_name(l))
 
-    def cata(self, t, f):
+    def l(self, v: A) -> 'amino.List[A]':
+        return self.m(v) / amino.List | amino.Nil
+
+    def cata(self, t: A, f: A) -> A:
         return t if self.value else f
 
     def cata_call(self, t, f):
