@@ -2,22 +2,23 @@ from types import GeneratorType
 from typing import TypeVar, Callable, Any, Generator, cast, Optional
 import functools
 
-from amino.tc.base import Implicits
+from amino.tc.base import F
 from amino.tc.monad import Monad
 
-F = TypeVar('F', bound=Implicits)
 A = TypeVar('A')
+B = TypeVar('B')
+G = TypeVar('G', bound=F)
 
 
-def do(f: Callable[..., Generator[F, A, F]]) -> Callable:
+def do(f: Callable[..., Generator[G, B, None]]) -> Callable[..., G]:
     @functools.wraps(f)
-    def do_loop(*a: Any, **kw: Any) -> F:
+    def do_loop(*a: Any, **kw: Any) -> F[B]:
         itr = f(*a, **kw)
         if not isinstance(itr, GeneratorType):
             raise Exception(f'function `{f.__qualname__}` decorated with `do` does not produce a generator')
         c: Optional[F] = None
         m: Optional[Monad[F]] = None
-        def send(val: A) -> F:
+        def send(val: B) -> F[B]:
             nonlocal c, m
             try:
                 c = itr.send(val)
@@ -25,7 +26,7 @@ def do(f: Callable[..., Generator[F, A, F]]) -> Callable:
                 return c.flat_map(send)
             except StopIteration:
                 return m.pure(val)
-        return send(cast(A, None))
+        return send(cast(B, None))
     return do_loop
 
-__all__ = ('do',)
+__all__ = ('do', 'F')
