@@ -1,5 +1,6 @@
+import abc
 import importlib
-from typing import TypeVar, Generic, Callable, Union, Any, cast, Iterator
+from typing import TypeVar, Generic, Callable, Union, Any, cast, Iterator, Type
 from types import ModuleType  # noqa
 from pathlib import Path
 
@@ -11,14 +12,19 @@ from amino.util.mod import unsafe_import_name
 from amino.tc.monoid import Monoid
 from amino.util.string import ToStr
 from amino.do import do
+from amino.util.exception import format_exception
 
 A = TypeVar('A')
 B = TypeVar('B')
 C = TypeVar('C')
+E = TypeVar('E', bound=Exception)
 
 
 class ImportFailure(ToStr):
-    pass
+
+    @abc.abstractproperty
+    def expand(self) -> 'amino.List[str]':
+        ...
 
 
 class ImportException(ImportFailure):
@@ -30,6 +36,10 @@ class ImportException(ImportFailure):
     def _arg_desc(self) -> 'amino.List[str]':
         return amino.List(self.desc, str(self.exc))
 
+    @property
+    def expand(self) -> 'amino.List[str]':
+        return format_exception(self.exc).cons(self.desc)
+
 
 class InvalidLocator(ImportFailure):
 
@@ -39,6 +49,10 @@ class InvalidLocator(ImportFailure):
     def _arg_desc(self) -> 'amino.List[str]':
         return amino.List(self.msg)
 
+    @property
+    def expand(self) -> 'amino.List[str]':
+        return amino.List(self.msg)
+
 
 class Either(Generic[A, B], F[B], implicits=True):
 
@@ -75,14 +89,17 @@ class Either(Generic[A, B], F[B], implicits=True):
 
     @staticmethod
     def import_file(path: Path) -> 'Either[ImportFailure, ModuleType]':
-        try:
-            spec = importlib.util.spec_from_file_location('temp', str(path))
+        from amino.maybe import Maybe
+        def step2(spec: importlib._bootstrap.ModuleSpec) -> ModuleType:
             module = importlib.util.module_from_spec(spec)
             spec.loader.exec_module(module)
+            return module
+        try:
+            module = Maybe.check(importlib.util.spec_from_file_location('temp', str(path))) / step2
         except Exception as e:
-            return Left(ImportException(path, e))
+            return Left(ImportException(str(path), e))
         else:
-            return Right(module)
+            return module.to_either(InvalidLocator(f'failed to import `{path}`'))
 
     @staticmethod
     @do
@@ -95,6 +112,13 @@ class Either(Generic[A, B], F[B], implicits=True):
             Right(attr)
         )
 
+    @staticmethod
+    def catch(f: Callable[[], B], exc: Type[E]) -> 'Either[E, B]':
+        try:
+            return Right(f())
+        except exc as e:
+            return Left(e)
+
     @property
     def is_right(self) -> 'amino.Boolean':
         return boolean.Boolean(isinstance(self, Right))
