@@ -8,9 +8,13 @@ class EnvOption:
     def __init__(self, name: str) -> None:
         self.name = name
 
-    def __bool__(self) -> bool:
+    @property
+    def exists(self) -> bool:
         return self.name in os.environ
 
+    def __bool__(self) -> bool:
+        return self.exists
+
     @property
     def value(self) -> 'amino.Maybe[str]':
         return amino.env[self.name]
@@ -19,8 +23,10 @@ class EnvOption:
         value = self.value.map(lambda a: f'={a}') | ' is unset'
         return f'{self.name}{value}'
 
+
 development = EnvOption('AMINO_DEVELOPMENT')
 integration_test = EnvOption('AMINO_INTEGRATION')
 anon_debug = EnvOption('AMINO_ANON_DEBUG')
+io_debug = EnvOption('AMINO_IO_DEBUG')
 
-__all__ = ('development', 'integration_test', 'anon_debug')
+__all__ = ('development', 'integration_test', 'anon_debug', 'io_debug')
